[−][src]Crate rustnomial
Re-exports
pub use crate::err::PolynomialFromStringError; |
pub use crate::err::TryAddError; |
pub use crate::terms::Degree; |
pub use crate::terms::Term; |
Modules
| err | |
| poly_math | |
| terms |
Macros
| derivative | |
| integral | |
| poly_add | |
| poly_mul | |
| poly_sub | |
| polynomial |
Structs
| Integral | |
| LinearBinomial | |
| Monomial | |
| Polynomial | |
| QuadraticTrinomial | |
| SparsePolynomial | This version of Polynomial is intended for use for polynomials of large degree, but with a very small number of internal terms. However, it is significantly slower than Polynomial in the case where the number of non-zero terms is close to the degree. |
Enums
| Roots |
Traits
| Derivable | |
| Evaluable | |
| FreeSizePolynomial | |
| Integrable | |
| MutablePolynomial | |
| SizedPolynomial |